# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .messages import (
    Messages,
    AsyncMessages,
    MessagesWithRawResponse,
    AsyncMessagesWithRawResponse,
    MessagesWithStreamingResponse,
    AsyncMessagesWithStreamingResponse,
)
from .prompt_caching import (
    PromptCaching,
    AsyncPromptCaching,
    PromptCachingWithRawResponse,
    AsyncPromptCachingWithRawResponse,
    PromptCachingWithStreamingResponse,
    AsyncPromptCachingWithStreamingResponse,
)

__all__ = [
    "Messages",
    "AsyncMessages",
    "MessagesWithRawResponse",
    "AsyncMessagesWithRawResponse",
    "MessagesWithStreamingResponse",
    "AsyncMessagesWithStreamingResponse",
    "PromptCaching",
    "AsyncPromptCaching",
    "PromptCachingWithRawResponse",
    "AsyncPromptCachingWithRawResponse",
    "PromptCachingWithStreamingResponse",
    "AsyncPromptCachingWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .message_create_params import MessageCreateParams as MessageCreateParams
from .prompt_caching_beta_usage import PromptCachingBetaUsage as PromptCachingBetaUsage
from .prompt_caching_beta_message import PromptCachingBetaMessage as PromptCachingBetaMessage
from .prompt_caching_beta_tool_param import PromptCachingBetaToolParam as PromptCachingBetaToolParam
from .prompt_caching_beta_message_param import PromptCachingBetaMessageParam as PromptCachingBetaMessageParam
from .prompt_caching_beta_text_block_param import PromptCachingBetaTextBlockParam as PromptCachingBetaTextBlockParam
from .prompt_caching_beta_image_block_param import PromptCachingBetaImageBlockParam as PromptCachingBetaImageBlockParam
from .prompt_caching_beta_tool_use_block_param import (
    PromptCachingBetaToolUseBlockParam as PromptCachingBetaToolUseBlockParam,
)
from .prompt_caching_beta_tool_result_block_param import (
    PromptCachingBetaToolResultBlockParam as PromptCachingBetaToolResultBlockParam,
)
from .raw_prompt_caching_beta_message_start_event import (
    RawPromptCachingBetaMessageStartEvent as RawPromptCachingBetaMessageStartEvent,
)
from .raw_prompt_caching_beta_message_stream_event import (
    RawPromptCachingBetaMessageStreamEvent as RawPromptCachingBetaMessageStreamEvent,
)
from .prompt_caching_beta_cache_control_ephemeral_param import (
    PromptCachingBetaCacheControlEphemeralParam as PromptCachingBetaCacheControlEphemeralParam,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .model import Model as Model
from .usage import Usage as Usage
from .message import Message as Message
from .beta_error import BetaError as BetaError
from .completion import Completion as Completion
from .text_block import TextBlock as TextBlock
from .text_delta import TextDelta as TextDelta
from .tool_param import ToolParam as ToolParam
from .model_param import ModelParam as ModelParam
from .content_block import ContentBlock as ContentBlock
from .message_param import MessageParam as MessageParam
from .beta_api_error import BetaAPIError as BetaAPIError
from .metadata_param import MetadataParam as MetadataParam
from .tool_use_block import ToolUseBlock as ToolUseBlock
from .input_json_delta import InputJSONDelta as InputJSONDelta
from .text_block_param import TextBlockParam as TextBlockParam
from .image_block_param import ImageBlockParam as ImageBlockParam
from .tool_choice_param import ToolChoiceParam as ToolChoiceParam
from .message_stop_event import MessageStopEvent as MessageStopEvent
from .beta_error_response import BetaErrorResponse as BetaErrorResponse
from .content_block_param import ContentBlockParam as ContentBlockParam
from .message_delta_event import MessageDeltaEvent as MessageDeltaEvent
from .message_delta_usage import MessageDeltaUsage as MessageDeltaUsage
from .message_start_event import MessageStartEvent as MessageStartEvent
from .anthropic_beta_param import AnthropicBetaParam as AnthropicBetaParam
from .beta_not_found_error import BetaNotFoundError as BetaNotFoundError
from .message_stream_event import MessageStreamEvent as MessageStreamEvent
from .tool_use_block_param import ToolUseBlockParam as ToolUseBlockParam
from .beta_overloaded_error import BetaOverloadedError as BetaOverloadedError
from .beta_permission_error import BetaPermissionError as BetaPermissionError
from .beta_rate_limit_error import BetaRateLimitError as BetaRateLimitError
from .message_create_params import MessageCreateParams as MessageCreateParams
from .tool_choice_any_param import ToolChoiceAnyParam as ToolChoiceAnyParam
from .raw_message_stop_event import RawMessageStopEvent as RawMessageStopEvent
from .tool_choice_auto_param import ToolChoiceAutoParam as ToolChoiceAutoParam
from .tool_choice_tool_param import ToolChoiceToolParam as ToolChoiceToolParam
from .raw_message_delta_event import RawMessageDeltaEvent as RawMessageDeltaEvent
from .raw_message_start_event import RawMessageStartEvent as RawMessageStartEvent
from .tool_result_block_param import ToolResultBlockParam as ToolResultBlockParam
from .completion_create_params import CompletionCreateParams as CompletionCreateParams
from .content_block_stop_event import ContentBlockStopEvent as ContentBlockStopEvent
from .raw_message_stream_event import RawMessageStreamEvent as RawMessageStreamEvent
from .beta_authentication_error import BetaAuthenticationError as BetaAuthenticationError
from .content_block_delta_event import ContentBlockDeltaEvent as ContentBlockDeltaEvent
from .content_block_start_event import ContentBlockStartEvent as ContentBlockStartEvent
from .beta_invalid_request_error import BetaInvalidRequestError as BetaInvalidRequestError
from .raw_content_block_stop_event import RawContentBlockStopEvent as RawContentBlockStopEvent
from .raw_content_block_delta_event import RawContentBlockDeltaEvent as RawContentBlockDeltaEvent
from .raw_content_block_start_event import RawContentBlockStartEvent as RawContentBlockStartEvent



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from ...._models import BaseModel
from .prompt_caching_beta_message import PromptCachingBetaMessage

__all__ = ["RawPromptCachingBetaMessageStartEvent"]


class RawPromptCachingBetaMessageStartEvent(BaseModel):
    message: PromptCachingBetaMessage

    type: Literal["message_start"]



from typing import Union
from typing_extensions import Literal

from ._types import (
    TextEvent,
    InputJsonEvent,
    RawMessageDeltaEvent,
    ContentBlockStopEvent,
    RawContentBlockDeltaEvent,
    RawContentBlockStartEvent,
)
from ...types import RawMessageStopEvent
from ...types.beta.prompt_caching import PromptCachingBetaMessage, RawPromptCachingBetaMessageStartEvent


class MessageStopEvent(RawMessageStopEvent):
    type: Literal["message_stop"]

    message: PromptCachingBetaMessage


PromptCachingBetaMessageStreamEvent = Union[
    RawPromptCachingBetaMessageStartEvent,
    MessageStopEvent,
    # same as non-beta
    TextEvent,
    InputJsonEvent,
    RawMessageDeltaEvent,
    RawContentBlockStartEvent,
    RawContentBlockDeltaEvent,
    ContentBlockStopEvent,
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Iterable
from typing_extensions import Literal, Required, TypedDict

from ...content_block import ContentBlock
from .prompt_caching_beta_text_block_param import PromptCachingBetaTextBlockParam
from .prompt_caching_beta_image_block_param import PromptCachingBetaImageBlockParam
from .prompt_caching_beta_tool_use_block_param import PromptCachingBetaToolUseBlockParam
from .prompt_caching_beta_tool_result_block_param import PromptCachingBetaToolResultBlockParam

__all__ = ["PromptCachingBetaMessageParam"]


class PromptCachingBetaMessageParam(TypedDict, total=False):
    content: Required[
        Union[
            str,
            Iterable[
                Union[
                    PromptCachingBetaTextBlockParam,
                    PromptCachingBetaImageBlockParam,
                    PromptCachingBetaToolUseBlockParam,
                    PromptCachingBetaToolResultBlockParam,
                    ContentBlock,
                ]
            ],
        ]
    ]

    role: Required[Literal["user", "assistant"]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

from .beta_base64_pdf_source_param import BetaBase64PDFSourceParam
from .beta_cache_control_ephemeral_param import BetaCacheControlEphemeralParam

__all__ = ["BetaBase64PDFBlockParam"]


class BetaBase64PDFBlockParam(TypedDict, total=False):
    source: Required[BetaBase64PDFSourceParam]

    type: Required[Literal["document"]]

    cache_control: Optional[BetaCacheControlEphemeralParam]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .messages import (
    Messages,
    AsyncMessages,
    MessagesWithRawResponse,
    AsyncMessagesWithRawResponse,
    MessagesWithStreamingResponse,
    AsyncMessagesWithStreamingResponse,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["PromptCaching", "AsyncPromptCaching"]


class PromptCaching(SyncAPIResource):
    @cached_property
    def messages(self) -> Messages:
        return Messages(self._client)

    @cached_property
    def with_raw_response(self) -> PromptCachingWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/anthropics/anthropic-sdk-python#accessing-raw-response-data-eg-headers
        """
        return PromptCachingWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PromptCachingWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/anthropics/anthropic-sdk-python#with_streaming_response
        """
        return PromptCachingWithStreamingResponse(self)


class AsyncPromptCaching(AsyncAPIResource):
    @cached_property
    def messages(self) -> AsyncMessages:
        return AsyncMessages(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncPromptCachingWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return the
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/anthropics/anthropic-sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPromptCachingWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPromptCachingWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/anthropics/anthropic-sdk-python#with_streaming_response
        """
        return AsyncPromptCachingWithStreamingResponse(self)


class PromptCachingWithRawResponse:
    def __init__(self, prompt_caching: PromptCaching) -> None:
        self._prompt_caching = prompt_caching

    @cached_property
    def messages(self) -> MessagesWithRawResponse:
        return MessagesWithRawResponse(self._prompt_caching.messages)


class AsyncPromptCachingWithRawResponse:
    def __init__(self, prompt_caching: AsyncPromptCaching) -> None:
        self._prompt_caching = prompt_caching

    @cached_property
    def messages(self) -> AsyncMessagesWithRawResponse:
        return AsyncMessagesWithRawResponse(self._prompt_caching.messages)


class PromptCachingWithStreamingResponse:
    def __init__(self, prompt_caching: PromptCaching) -> None:
        self._prompt_caching = prompt_caching

    @cached_property
    def messages(self) -> MessagesWithStreamingResponse:
        return MessagesWithStreamingResponse(self._prompt_caching.messages)


class AsyncPromptCachingWithStreamingResponse:
    def __init__(self, prompt_caching: AsyncPromptCaching) -> None:
        self._prompt_caching = prompt_caching

    @cached_property
    def messages(self) -> AsyncMessagesWithStreamingResponse:
        return AsyncMessagesWithStreamingResponse(self._prompt_caching.messages)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

from .prompt_caching_beta_cache_control_ephemeral_param import PromptCachingBetaCacheControlEphemeralParam

__all__ = ["PromptCachingBetaTextBlockParam"]


class PromptCachingBetaTextBlockParam(TypedDict, total=False):
    text: Required[str]

    type: Required[Literal["text"]]

    cache_control: Optional[PromptCachingBetaCacheControlEphemeralParam]
